@@ -42,6 +42,22 @@
 (require 'imenu)
 
 
+;; ---------------------------------------------------------------------------
+;; Compatibility
+
+(when (and (version< emacs-version "31.1") (not (and (fboundp 'incf) (fboundp 'decf))))
+  (defmacro incf (place &optional delta)
+    "Increment PLACE by DELTA or 1."
+    (declare (debug (gv-place &optional form)))
+    (gv-letplace (getter setter) place
+      (funcall setter `(+ ,getter ,(or delta 1)))))
+  (defmacro decf (place &optional delta)
+    "Decrement PLACE by DELTA or 1."
+    (declare (debug (gv-place &optional form)))
+    (gv-letplace (getter setter) place
+      (funcall setter `(- ,getter ,(or delta 1))))))
+
+
 ;; ---------------------------------------------------------------------------
 ;; Custom Variables
 
@@ -352,8 +368,7 @@ the point should not be moved by this function."
                ;; so `looking-at-p' works as expected.
                (goto-char (pos-bol))
                (while (and (looking-at-p "[[:blank:]]*$")
-                           (< (setq blank-lines (1+ blank-lines))
-                              doc-show-inline-exclude-blank-lines)
+                           (< (incf blank-lines) doc-show-inline-exclude-blank-lines)
                            (zerop (forward-line -1)))))
              (eq blank-lines doc-show-inline-exclude-blank-lines)))
 
